@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global document, EzWebExt, LayoutManagerFactory, gettext, interpolate, StyledElements, Wirecloud */
+/*global document, LayoutManagerFactory, gettext, interpolate, StyledElements, Wirecloud */
 
 (function () {
 
@@ -35,7 +35,7 @@
         this.structure_template = resource_template;
         this.error_template = '<s:styledgui xmlns:s="http://wirecloud.conwet.fi.upm.es/StyledElements" xmlns:t="http://wirecloud.conwet.fi.upm.es/Template" xmlns="http://www.w3.org/1999/xhtml"><div class="alert alert-block alert-error"><t:message/></div></s:styledgui>';
         this.container = container;
-        if (typeof extra_context === 'object' || typeof extra_context === 'function') {
+        if (extra_context != null && (typeof extra_context === 'object' || typeof extra_context === 'function')) {
             this.extra_context = extra_context;
         } else {
             this.extra_context = {};
@@ -53,22 +53,28 @@
     };
 
     ResourcePainter.prototype.paint = function paint(resource) {
-        var extra_context, i, context, resource_element;
+        var extra_context, i, context, resource_element, license_text;
 
         if (typeof this.extra_context === 'function') {
             extra_context = this.extra_context(resource);
         } else {
-            extra_context = EzWebExt.clone(this.extra_context);
+            extra_context = Wirecloud.Utils.clone(this.extra_context);
         }
 
-        context = EzWebExt.merge(extra_context, {
-            'displayname': resource.getDisplayName(),
+        if (resource.license != null && resource.license != '') {
+            license_text = resource.license;
+        } else {
+            license_text = 'N/A';
+        }
+
+        context = Wirecloud.Utils.merge(extra_context, {
+            'displayname': resource.displayname,
             'name': resource.name,
-            'internalname': resource.getURI(),
+            'internalname': resource.uri,
             'vendor': resource.vendor,
             'version': resource.version.text,
-            'author': resource.getCreator(),
-            'description': resource.getDescription(),
+            'authors': resource.authors,
+            'description': resource.description,
             'type': function () {
                 var label = document.createElement('div');
                 label.textContent = resource.type;
@@ -100,7 +106,7 @@
                     'title': gettext('Documentation')
                 });
                 button.addEventListener('click', function () {
-                    window.open(resource.getUriWiki(), '_blank');
+                    window.open(resource.doc_url, '_blank');
                 });
 
                 return button;
@@ -114,11 +120,31 @@
                     'title': gettext('Home page')
                 });
                 button.addEventListener('click', function () {
-                    window.open(resource.getUriWiki(), '_blank');
+                    window.open(resource.doc_url, '_blank');
                 });
 
                 return button;
             },
+            'license': license_text,
+            'license_home': function () {
+                var button;
+
+                button = new StyledElements.StyledButton({
+                    'plain': true,
+                    'class': 'icon-legal',
+                    'title': gettext('License details')
+                });
+
+                if (resource.licenseurl != null && resource.licenseurl != '') {
+                    button.addEventListener('click', function () {
+                        window.open(resource.licenseurl, '_blank');
+                    });
+                } else {
+                    button.disable();
+                }
+
+                return button;
+            },
             'rating': this.get_popularity_html.bind(this, resource.rating),
             'mainbutton': function () {
                 var button, local_catalogue_view;
@@ -163,7 +189,7 @@
                     default:
                         button = new StyledElements.StyledButton({text: gettext('Download')});
                         button.addEventListener('click', function (resource) {
-                            window.open(resource.getUriTemplate(), '_blank');
+                            window.open(resource.description_url, '_blank');
                         }.bind(null, this.resource));
                     }
                 } else {
@@ -195,7 +221,7 @@
                 image.onerror = function (event) {
                     event.target.src = '/static/images/noimage.png';
                 };
-                image.src = resource.getUriImage();
+                image.src = resource.image;
                 return image;
             },
             'tags': function (options) {
@@ -219,10 +245,13 @@
 
         // TODO "Show details"
         for (i = 0; i < resource_element.elements.length; i += 1) {
-            if (!EzWebExt.XML.isElement(resource_element.elements[i])) {
+            if (!Wirecloud.Utils.XML.isElement(resource_element.elements[i])) {
                 continue;
             }
             this.create_simple_command(resource_element.elements[i], '.click_for_details', 'click', this.catalogue_view.createUserCommand('showDetails', resource));
+            if (resource_element.elements[i].classList.contains('click_for_details')) {
+                resource_element.elements[i].addEventListener('click', this.catalogue_view.createUserCommand('showDetails', resource));
+            }
         }
 
         return resource_element;
@@ -235,7 +264,7 @@
             'text': gettext('Download')
         });
         button.addEventListener('click', function () {
-            window.open(resource.getUriTemplate(), '_blank');
+            window.open(resource.description_url, '_blank');
         });
         fragment.appendChild(button);
 
@@ -247,7 +276,7 @@
             fragment.appendChild(button);
         }
 
-        if (Wirecloud.LocalCatalogue.resourceExists(resource)) {
+        if (Wirecloud.LocalCatalogue.resourceExists(resource) && resource.isAllow('uninstall')) {
             var local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
             button = new StyledElements.StyledButton({
                 'class': 'btn-danger',
@@ -283,7 +312,7 @@
 
         fragment = new StyledElements.Fragment();
 
-        tags = resource.getTags();
+        tags = resource.tags.slice();
         tags = tags.sort(function (a, b) {
             return b.apparences - a.apparences;
         });
@@ -305,7 +334,7 @@
     };
 
     ResourcePainter.prototype.create_simple_command = function (element, selector, _event, handler, required) {
-        var i, elements = element.getElementsBySelector(selector);
+        var i, elements = element.querySelectorAll(selector);
 
         if (required && elements.length < 1) {
             throw new Error();
@@ -319,6 +348,10 @@
     ResourcePainter.prototype.get_popularity_html = function (popularity) {
         var on_stars, md_star, off_stars, stars, star, i;
 
+        if (popularity == null || popularity < 1) {
+            popularity = 0;
+        }
+
         on_stars = Math.floor(popularity);
         md_star = popularity - on_stars;
         off_stars = 5 - popularity;
@@ -326,6 +359,10 @@
         stars = document.createElement('div');
         stars.className = 'rating';
 
+        if (popularity === 0) {
+            stars.classList.add('disabled');
+        }
+
         // "On" stars
         for (i = 0; i < on_stars; i += 1) {
             star = document.createElement('span');
@@ -335,7 +372,7 @@
 
         if (md_star) {
             star = document.createElement('span');
-            star.className = 'md star';
+            star.className = 'middle star';
             stars.appendChild(star);
         }
 
