@@ -1,4 +1,4 @@
-/*global $, document, gettext, interpolate, Element, EzWebExt, Form, OpManagerFactory, SelectInputInterface, StyledElements, Wirecloud */
+/*global gettext, interpolate, Form, SelectInputInterface, StyledElements, Wirecloud */
 "use strict";
 
 var ValidationErrorManager, InputValidationError = {};
@@ -69,7 +69,7 @@ ValidationErrorManager.prototype._buildErrorMsg = function _buildErrorMsg(errorC
     }
 
     fields = fields.substring(2);
-    return EzWebExt.interpolate(msg, {'fields': fields});
+    return Wirecloud.Utils.interpolate(msg, {'fields': fields});
 };
 
 ValidationErrorManager.prototype.toHTML = function toHTML() {
@@ -84,238 +84,6 @@ ValidationErrorManager.prototype.toHTML = function toHTML() {
     return errorMsgs;
 };
 
-
-/**
- * @abstract
- */
-var InputInterface = function InputInterface(fieldId, options) {
-    if (arguments.length === 0) {
-        return;
-    }
-
-    StyledElements.StyledElement.call(this, []);
-
-    options.name = fieldId;
-    this._fieldId = fieldId;
-    this._initialValue = options.initialValue;
-    this._defaultValue = options.defaultValue;
-    this._label = options.label;
-    Object.defineProperty(this, 'required', {value: 'required' in options ? !!options.required : false});
-    this._readOnly = !!options.readOnly;
-    this._hidden = !!options.hidden;
-
-    if (options.description) {
-        this._description = options.description;
-    } else {
-        this._description = options.label;
-    }
-};
-InputInterface.prototype = new StyledElements.StyledElement();
-
-InputInterface.prototype.repaint = function repaint() {
-    this.inputElement.repaint();
-};
-
-InputInterface.prototype.getValue = function getValue() {
-    return this.inputElement.getValue();
-};
-
-InputInterface.prototype.setValue = function setValue(newValue) {
-    if (this.isValidValue(newValue)) {
-        this._setValue(newValue);
-    }
-};
-
-/**
- * Returns the label for this InputInterface.
- *
- * @returns {String}
- */
-InputInterface.prototype.getLabel = function getLabel() {
-    return this._label;
-};
-
-/**
- * Returns the description for this InputInterface.
- *
- * @returns {String}
- */
-InputInterface.prototype.getDescription = function getDescription() {
-    return this._description;
-};
-
-/**
- * Returns the defaultValue for this InputInterface.
- *
- * @returns {Object}
- */
-InputInterface.prototype.getDefaultValue = function getDefaultValue() {
-    return this._defaultValue;
-};
-
-/**
- * Checks if this InputInterface is currently empty.
- *
- * @returns {Boolean}
- */
-InputInterface.prototype.isEmpty = function isEmpty() {
-    return this._isEmptyValue(this.getValue());
-};
-
-/**
- * Checks if value is considered Empty by this InputInterface.
- * The value must be normalized before doing the check.
- *
- * @returns {Boolean}
- */
-InputInterface.prototype._isEmptyValue = function _isEmptyValue(value) {
-    return value === "" || value == null;
-};
-
-InputInterface.prototype._normalize = function _normalize(value) {
-    if (value == null) {
-        return value;
-    } else {
-        return ("" + value).strip();
-    }
-};
-
-/**
- * @private
- *
- * Must be implemented by child classes. This method checks that the given value
- * is valid for this <code>InputInterface</code>. Things as checking if the
- * value is empty but required is out of scope of this method.
- */
-InputInterface.prototype._checkValue = function _checkValue(newValue) {
-    return InputValidationError.NO_ERROR;
-};
-
-/**
- * Checks if the given value is valid for this InputInterface.
- *
- */
-InputInterface.prototype.checkValue = function checkValue(newValue) {
-    if (newValue === undefined) {
-        newValue = this.getValue();
-    } else {
-        newValue = this._normalize(newValue);
-    }
-
-    if (!(this instanceof SelectInputInterface)) {
-        if (this.required && this._isEmptyValue(newValue)) {
-            return InputValidationError.REQUIRED_ERROR;
-        }
-
-        if (!this.required && this._isEmptyValue(newValue)) {
-            return InputValidationError.NO_ERROR;
-        }
-    }
-
-    return this._checkValue(newValue);
-};
-
-/**
- * Checks if the given value is valid for this InputInterface.
- *
- * @retuns {Boolean}
- */
-InputInterface.prototype.isValidValue = function isValidValue(newValue) {
-    return this.checkValue(newValue) === InputValidationError.NO_ERROR;
-};
-
-/**
- * Sets the value for this interface without checking its correctness.
- *
- * @param newValue
- *
- * @see <code>InputInterface.setValue</code>
- */
-InputInterface.prototype._setValue = function _setValue(newValue) {
-    if (newValue === null || newValue === undefined) {
-        newValue = "";
-    }
-
-    this.inputElement.setValue(newValue);
-};
-
-/**
- * Sets the error status for this interface.
- *
- * @param {Boolean} error
- */
-InputInterface.prototype._setError = function _setError(error) {
-    if (error) {
-        this.inputElement.wrapperElement.classList.add('error');
-    } else {
-        this.inputElement.wrapperElement.classList.remove('error');
-    }
-};
-
-/**
- * Resets the current interface using its default value.
- */
-InputInterface.prototype.resetToDefault = function resetToDefault() {
-    this._setError(false);
-    this._setValue(this._defaultValue);
-};
-
-/**
- * Resets the current interface using the initial value.
- */
-InputInterface.prototype.reset = function reset() {
-    this._setError(false);
-    this._setValue(this._initialValue);
-};
-
-/**
- * Sets the focus on this input interface.
- */
-InputInterface.prototype.focus = function focus() {
-
-    this.inputElement.focus();
-};
-
-/**
- * Disables/enables this input interface.
- */
-InputInterface.prototype.setDisabled = function setDisabled(disable) {
-    this.inputElement.setDisabled(this._readOnly || disable);
-};
-
-/**
- * Enables this input interface.
- */
-InputInterface.prototype.enable = function enable() {
-    this.setDisabled(false);
-};
-
-/**
- * Disables this input interface.
- */
-InputInterface.prototype.disable = function disable() {
-    this.setDisabled(true);
-};
-
-/**
- * Inserts this InputInterface into the given DOM Element.
- *
- * @param {Element} element
- */
-InputInterface.prototype.insertInto = function insertInto(element) {
-    this.inputElement.insertInto(element);
-};
-
-/**
- *
- * @param {String} value
- *
- * @return {Object}
- */
-InputInterface.prototype.parseFromPersistence = function parseFromPersistence(value) {
-    return value;
-};
-
 /**
  *
  */
@@ -330,6 +98,12 @@ function TextInputInterface(fieldId, options) {
 }
 TextInputInterface.prototype = new InputInterface();
 
+TextInputInterface.prototype.assignDefaultButton = function assignDefaultButton(button) {
+    this.inputElement.addEventListener('submit', function () {
+        button.click();
+    });
+};
+
 /**
  *
  */
@@ -786,130 +560,6 @@ FieldSetInterface.prototype._setError = function _setError(error) {
     // TODO
 };
 
-/**
- *
- */
-function ParametrizableValueInputInterface(fieldId, options) {
-    InputInterface.call(this, fieldId, options);
-
-    this.parentWindow = options.parentWindow;
-    this.variable = options.variable;
-    this.canBeHidden = options.canBeHidden;
-
-    this.wrapperElement = document.createElement('div');
-    this.wrapperElement.className = "parametrizable_input";
-
-    this.readOnlyIcon = document.createElement('div');
-    this.readOnlyIcon.addClassName('readOnlyIcon');
-    this.wrapperElement.appendChild(this.readOnlyIcon);
-
-    this.visibilityIcon = document.createElement('div');
-    this.visibilityIcon.addClassName('visibilityIcon');
-    this.wrapperElement.appendChild(this.visibilityIcon);
-    if (!this.canBeHidden) {
-        this.visibilityIcon.style.visibility = 'hidden';
-    }
-
-    this.inputElement = new StyledElements.StyledTextField();
-    this.inputElement.disable();
-    this.inputElement.insertInto(this.wrapperElement);
-
-    this.buttonElement = new StyledElements.StyledButton({text: ''});
-    this.buttonElement.addEventListener('click', function () {
-        var dialog = new Wirecloud.ui.ParametrizeWindowMenu(this);
-        dialog.show(this.parentWindow);
-        dialog.setValue(this.getValue());
-    }.bind(this));
-    this.buttonElement.insertInto(this.wrapperElement);
-}
-ParametrizableValueInputInterface.prototype = new InputInterface();
-
-ParametrizableValueInputInterface.prototype._checkValue = function _checkValue(newValue) {
-    return InputValidationError.NO_ERROR;
-};
-
-ParametrizableValueInputInterface.prototype.getValue = function getValue() {
-    var value = {
-        'source': this.source,
-        'status': this.status
-    };
-
-    if (this.source !== 'default') {
-        value.value = this.inputElement.getValue();
-    }
-
-    return value;
-};
-
-ParametrizableValueInputInterface.prototype.VALID_SOURCE_VALUES = ['current', 'default', 'custom'];
-ParametrizableValueInputInterface.prototype.VALID_STATUS_VALUES = ['normal', 'hidden', 'readonly'];
-
-ParametrizableValueInputInterface.prototype._setValue = function _setValue(newValue) {
-    if (newValue == null || this.VALID_SOURCE_VALUES.indexOf(newValue.source) === -1) {
-        this.source = 'current';
-    } else {
-        this.source = newValue.source;
-    }
-
-    if (newValue == null || typeof newValue.value !== 'string') {
-        this.value = '';
-    } else {
-        this.value = newValue.value;
-    }
-
-    if (newValue == null || this.VALID_STATUS_VALUES.indexOf(newValue.status) === -1) {
-        this.status = 'normal';
-    } else if (!this.canBeHidden && newValue.status === 'hidden') {
-        this.status = 'readOnly';
-    } else {
-        this.status = newValue.status;
-    }
-
-    this._updateInputElement();
-    this._updateButton();
-};
-
-ParametrizableValueInputInterface.prototype.insertInto = function insertInto(element) {
-    element.appendChild(this.wrapperElement);
-};
-
-ParametrizableValueInputInterface.prototype._updateInputElement = function _updateInputElement() {
-    switch (this.source) {
-    case 'default':
-        this.inputElement.setValue('');
-        break;
-    case 'current':
-        this.inputElement.setValue(ParametrizedTextInputInterface.prototype.escapeValue(this.variable.value));
-        break;
-    case 'custom':
-        this.inputElement.setValue(this.value);
-    }
-};
-
-ParametrizableValueInputInterface.prototype._updateButton = function _updateButton() {
-    if (this.source === 'default') {
-        this.buttonElement.setLabel(gettext('Parametrize'));
-    } else {
-        this.buttonElement.setLabel(gettext('Modify'));
-    }
-
-    if (this.status !== 'normal') {
-        this.readOnlyIcon.addClassName('readOnly');
-        this.readOnlyIcon.title = gettext("This value won't be editable by the user");
-    } else {
-        this.readOnlyIcon.removeClassName('readOnly');
-        this.readOnlyIcon.title = gettext("This value will be editable by the user");
-    }
-
-    if (this.status !== 'hidden') {
-        this.visibilityIcon.addClassName('visible');
-        this.visibilityIcon.title = gettext("This value will be visible to the user");
-    } else {
-        this.visibilityIcon.removeClassName('visible');
-        this.visibilityIcon.title = gettext("This value won't be visible to the user");
-    }
-};
-
 /**
  *
  */
@@ -948,12 +598,12 @@ function ParametrizedTextInputInterface(fieldId, options) {
             this.mainSelect.add(option);
         }
     }
-    Element.observe(this.mainSelect, 'change', this._updateSecondSelect.bind(this));
+    this.mainSelect.addEventListener('change', this._updateSecondSelect.bind(this), true);
     this.selectorWrapperElement.appendChild(this.mainSelect);
 
     this.secondSelect = document.createElement('select');
     this.selectorWrapperElement.appendChild(this.secondSelect);
-    Element.observe(this.secondSelect, 'change', this._updateDescription.bind(this));
+    this.secondSelect.addEventListener('change', this._updateDescription.bind(this), true);
 
     this.addButton = new StyledElements.StyledButton({
         'text': gettext('Add')
@@ -1003,28 +653,26 @@ ParametrizedTextInputInterface.prototype.getAvailableParameters = function getAv
     var concepts, contextFields, conceptName, dashIndex, provider, concept, parameters, label;
 
     if (ParametrizedTextInputInterface.prototype._CONTEXT_PARAMS === null) {
-        concepts = OpManagerFactory.getInstance().activeWorkspace.contextManager._concepts;
+        concepts = Wirecloud.activeWorkspace.contextManager._concepts;
         contextFields = {
             '': []
         };
         for (conceptName in concepts) {
             concept = concepts[conceptName];
-            if (concept._type !== 'GCTX') {
-                dashIndex = conceptName.indexOf('-');
-                provider = conceptName.substring(0, dashIndex);
-                if (!(provider in contextFields)) {
-                    contextFields[provider] = [];
-                }
-                label = interpolate('%(label)s (%(concept)s)', {
-                    label: concept._label,
-                    concept: conceptName
-                }, true);
-                contextFields[provider].push({
-                    label: label,
-                    description: concept._description,
-                    value: conceptName
-                });
+            dashIndex = conceptName.indexOf('-');
+            provider = conceptName.substring(0, dashIndex);
+            if (!(provider in contextFields)) {
+                contextFields[provider] = [];
             }
+            label = interpolate('%(label)s (%(concept)s)', {
+                label: concept._label,
+                concept: conceptName
+            }, true);
+            contextFields[provider].push({
+                label: label,
+                description: concept._description,
+                value: conceptName
+            });
         }
 
         parameters = [
