@@ -19,7 +19,7 @@
  *
  */
 
-/*global CommandQueue, CSSPrimitiveValue, EzWebExt, StyledElements*/
+/*global CommandQueue, CSSPrimitiveValue, StyledElements, Wirecloud*/
 
 (function () {
 
@@ -51,10 +51,10 @@
             'focusOnSetVisible': true,
             'full': true
         };
-        options = EzWebExt.merge(defaultOptions, options);
+        options = Wirecloud.Utils.merge(defaultOptions, options);
 
         this.wrapperElement = document.createElement("div");
-        this.wrapperElement.className = EzWebExt.prependWord(options['class'], "notebook");
+        this.wrapperElement.className = Wirecloud.Utils.prependWord(options['class'], "notebook");
 
         var div = document.createElement("div");
         this.wrapperElement.appendChild(div);
@@ -183,6 +183,20 @@
         this.moveRightButton.addEventListener("click",
                                              this.shiftRightTabs.bind(this),
                                              true);
+
+        Object.defineProperty(this, 'fullscreen', {
+            get: function () {
+                if ('fullscreenElement' in document) {
+                    return document.fullscreenElement === this.wrapperElement;
+                } else if ('msFullscreenElement' in document) {
+                    return document.msFullscreenElement === this.wrapperElement;
+                } else if ('mozFullScreenElement' in document) {
+                    return document.mozFullScreenElement === this.wrapperElement;
+                } else if ('webkitFullscreenElement' in document) {
+                    return document.webkitFullscreenElement === this.wrapperElement;
+                }
+            }
+        });
     };
     StyledNotebook.prototype = new StyledElements.StyledElement();
 
@@ -298,7 +312,7 @@
             'name': '',
             'tab_constructor': StyledElements.Tab
         };
-        options = EzWebExt.merge(defaultOptions, options);
+        options = Wirecloud.Utils.merge(defaultOptions, options);
 
         // Reserve an id for the new tab
         var tabId = this.tabsById.push(null);
@@ -510,12 +524,16 @@
         var i, height, tabElement;
         temporal = temporal !== undefined ? temporal: false;
 
-        height = this._getUsableHeight();
-        if (height == null) {
-            return; // nothing to do
-        }
+        if (this.fullscreen !== true) {
+            height = this._getUsableHeight();
+            if (height == null) {
+                return; // nothing to do
+            }
 
-        this.wrapperElement.style.height = (height + "px");
+            this.wrapperElement.style.height = (height + "px");
+        } else {
+            this.wrapperElement.style.height = '';
+        }
 
         this.tabWrapper.repaint();
 
@@ -561,7 +579,7 @@
             this.disabledLayer.classList.add('disable-layer');
             this.wrapperElement.appendChild(this.disabledLayer);
         } else {
-            EzWebExt.removeFromParent(this.disabledLayer);
+            Wirecloud.Utils.removeFromParent(this.disabledLayer);
             this.disabledLayer = null;
         }
         this.enabled = !disabled;
@@ -588,16 +606,44 @@
     };
 
     StyledNotebook.prototype.addButton = function addButton(button) {
-        if (!(button instanceof StyledElements.StyledButton)) {
+        if (!(button instanceof StyledElements.StyledButton) && !(button instanceof StyledElements.StyledSelect)) {
             throw new TypeError();
         }
 
         this.tabWrapper.getEastContainer().appendChild(button);
     };
 
+    StyledNotebook.prototype.requestFullscreen = function requestFullscreen() {
+        if ('requestFullscreen' in this.wrapperElement) {
+            this.wrapperElement.requestFullscreen();
+        } else if ('msRequestFullscreen' in this.wrapperElement) {
+            this.wrapperElement.msRequestFullscreen();
+        } else if ('mozRequestFullScreen' in this.wrapperElement) {
+            this.wrapperElement.mozRequestFullScreen();
+        } else if ('webkitRequestFullscreen' in this.wrapperElement) {
+            this.wrapperElement.webkitRequestFullscreen();
+        }
+    };
+
+    StyledNotebook.prototype.exitFullscreen = function exitFullscreen() {
+        if (this.fullscreen !== true) {
+            return;
+        }
+
+        if ('exitFullscreen' in document) {
+            document.exitFullscreen();
+        } else if ('msExitFullscreen' in document) {
+            document.msExitFullscreen();
+        } else if ('mozCancelFullScreen' in document) {
+            document.mozCancelFullScreen();
+        } else if ('webkitExitFullscreen' in document) {
+            document.webkitExitFullscreen();
+        }
+    };
+
     StyledNotebook.prototype.destroy = function destroy() {
-        if (EzWebExt.XML.isElement(this.wrapperElement.parentNode)) {
-            EzWebExt.removeFromParent(this.wrapperElement);
+        if (Wirecloud.Utils.XML.isElement(this.wrapperElement.parentNode)) {
+            Wirecloud.Utils.removeFromParent(this.wrapperElement);
         }
 
         this.tabs = null;
