@@ -24,7 +24,7 @@
  */
 
 
-/*global Constants, Dragboard, gettext, interpolate, LayoutManagerFactory, PreferencesManagerFactory, TabMenuItems, StyledElements, Wirecloud*/
+/*global Dragboard, gettext, interpolate, LayoutManagerFactory, TabMenuItems, StyledElements, Wirecloud*/
 
 (function () {
 
@@ -42,30 +42,22 @@
     };
 
     var renameError = function renameError(transport, e) {
-        var layoutManager, msg;
-
-        layoutManager = LayoutManagerFactory.getInstance();
-
-        msg = Wirecloud.GlobaLogManager.formatError(gettext("Error renaming tab: %(errorMsg)s."), transport, e);
-        layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        var msg = Wirecloud.GlobaLogManager.formatError(gettext("Error renaming tab: %(errorMsg)s."), transport, e);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
     };
 
     var deleteSuccess = function deleteSuccess(transport) {
         var layoutManager = LayoutManagerFactory.getInstance();
 
-        this.workspace.unloadTab(this.getId());
+        this.workspace.unloadTab(this.id);
 
         layoutManager.logSubTask(gettext('Tab deleted successfully'));
         layoutManager.logStep('');
     };
 
     var deleteError = function deleteError(transport, e) {
-        var layoutManager, msg;
-
-        layoutManager = LayoutManagerFactory.getInstance();
-
-        msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error removing tab: %(errorMsg)s."), transport, e);
-        layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error removing tab: %(errorMsg)s."), transport, e);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
     };
 
     /**
@@ -73,7 +65,7 @@
      *
      * This method is called when tab preferences are changed
      */
-    var preferencesChanged = function preferencesChanged(modifiedValues) {
+    var preferencesChanged = function preferencesChanged(preferences, modifiedValues) {
         var preferenceName, newLayout;
 
         for (preferenceName in modifiedValues) {
@@ -112,41 +104,44 @@
         options.closable = false;
         StyledElements.Tab.call(this, id, notebook, options);
 
+        Object.defineProperty(this, 'id', {value: tabInfo.id});
+        Object.defineProperty(this, 'workspace', {value: options.workspace});
+
         this.addEventListener('show', function (tab) {
             tab.paint();
         });
 
-        this.menu_button = new StyledElements.PopupButton({
-            'class': 'icon-tab-menu',
-            'plain': true,
-            'menuOptions': {
-                'position': ['top-left', 'top-right']
-            }
-        });
-        this.menu_button.getPopupMenu().append(new TabMenuItems(this));
-        this.menu_button.insertInto(this.tabElement);
+        if (!this.workspace.restricted) {
+            this.menu_button = new StyledElements.PopupButton({
+                'class': 'icon-tab-menu',
+                'plain': true,
+                'menuOptions': {
+                    'position': ['top-left', 'top-right']
+                }
+            });
+            this.menu_button.getPopupMenu().append(new TabMenuItems(this));
+            this.menu_button.insertInto(this.tabElement);
+        }
 
-        // The name of the dragboard HTML elements correspond to the Tab name
-        this.workspace = options.workspace;
         this.tabInfo = tabInfo;
-        this.dragboardLayerName = "dragboard_" + this.workspace.workspaceState.id + "_" + this.tabInfo.id;
-        this.tabName = "tab_" + this.workspace.workspaceState.id + "_" + this.tabInfo.id;
+        this.dragboardLayerName = "dragboard_" + this.workspace.workspaceState.id + "_" + this.id;
 
         this.FloatingWidgetsMenu = null;
 
-        this.preferences = PreferencesManagerFactory.getInstance().buildPreferences('tab', this.tabInfo.preferences, this);
-        this.preferences.addCommitHandler(preferencesChanged.bind(this));
+        this.preferences = Wirecloud.PreferenceManager.buildPreferences('tab', this.tabInfo.preferences, this);
+        this.preferences.addEventListener('pre-commit', preferencesChanged.bind(this));
 
-        this.readOnly = false;
+        this.readOnly = this.workspace.restricted;
 
         this.dragboard = new Dragboard(this, this.workspace, this.wrapperElement);
 
         this.markAsVisible = function markAsVisible() {
-            var tabUrl = Wirecloud.URLs.TAB_ENTRY.evaluate({'workspace_id': this.workspace.workspaceState.id, 'tab_id': this.tabInfo.id});
+            var tabUrl = Wirecloud.URLs.TAB_ENTRY.evaluate({'workspace_id': this.workspace.workspaceState.id, 'tab_id': this.id});
             Wirecloud.io.makeRequest(tabUrl, {
                 method: 'POST',
                 contentType: 'application/json',
-                postBody: Object.toJSON({visible: "true"}),
+                requestHeaders: {'Accept': 'application/json'},
+                postBody: JSON.stringify({visible: "true"}),
                 onSuccess: this.markAsVisibleSuccess,
                 onFailure: this.markAsVisibleError,
                 onException: this.markAsVisibleError
@@ -154,9 +149,8 @@
         }.bind(this);
 
         this.markAsVisibleSuccess = function markAsVisibleSuccess() {
-            var tabIds = this.workspace.tabInstances.keys();
-            for (var i = 0; i < tabIds.length; i++) {
-                var tab = this.workspace.tabInstances.get(tabIds[i]);
+            for (var key in this.workspace.tabInstances) {
+                var tab = this.workspace.tabInstances[key];
                 tab.tabInfo.visible = false;
             }
             this.tabInfo.visible = true;
@@ -172,10 +166,6 @@
     // PUBLIC METHODS
     // ****************
 
-    Tab.prototype.getId = function getId() {
-        return this.tabInfo.id;
-    };
-
     Tab.prototype.getName = function getName() {
         return this.tabInfo.name;
     };
@@ -186,7 +176,7 @@
     Tab.prototype.updateInfo = function updateInfo(tabName) {
         var layoutManager, tabUrl, msg = null;
 
-        tabName = tabName.strip();
+        tabName = tabName.trim();
 
         if (tabName === "") {
             msg = interpolate(gettext("Error updating a tab: invalid name"), true);
@@ -205,11 +195,12 @@
         msg = interpolate(msg, {tabname: this.tabInfo.name, newname: tabName}, true);
         layoutManager.logSubTask(msg);
 
-        tabUrl = Wirecloud.URLs.TAB_ENTRY.evaluate({'workspace_id': this.workspace.workspaceState.id, 'tab_id': this.tabInfo.id});
+        tabUrl = Wirecloud.URLs.TAB_ENTRY.evaluate({'workspace_id': this.workspace.workspaceState.id, 'tab_id': this.id});
         Wirecloud.io.makeRequest(tabUrl, {
             method: 'PUT',
             contentType: 'application/json',
-            postBody: Object.toJSON({'name': tabName}),
+            requestHeaders: {'Accept': 'application/json'},
+            postBody: JSON.stringify({'name': tabName}),
             onSuccess: renameSuccess.bind({tab: this, newName: tabName}),
             onFailure: renameError,
             onException: renameError,
@@ -228,9 +219,10 @@
         msg = interpolate(msg, {tabname: this.tabInfo.name}, true);
         layoutManager.logSubTask(msg);
 
-        tabUrl = Wirecloud.URLs.TAB_ENTRY.evaluate({'workspace_id': this.workspace.workspaceState.id, 'tab_id': this.tabInfo.id});
+        tabUrl = Wirecloud.URLs.TAB_ENTRY.evaluate({'workspace_id': this.workspace.workspaceState.id, 'tab_id': this.id});
         Wirecloud.io.makeRequest(tabUrl, {
             method: 'DELETE',
+            requestHeaders: {'Accept': 'application/json'},
             onSuccess: deleteSuccess.bind(this),
             onFailure: deleteError,
             onException: deleteError,
@@ -248,6 +240,10 @@
         return this.dragboard;
     };
 
+    Tab.prototype.getIWidgets = function getIWidgets() {
+        return this.dragboard.getIWidgets();
+    };
+
     /**
     * Gets the banner related to the workspace this dragboard belongs to
     */
@@ -281,7 +277,7 @@
     Tab.prototype.isAllowed = function isAllowed(action) {
         switch (action) {
         case "remove":
-            return !this.readOnly && this.workspace.tabInstances.keys().length > 1 && !this.hasReadOnlyIWidgets();
+            return !this.readOnly && Object.keys(this.workspace.tabInstances).length > 1 && !this.hasReadOnlyIWidgets();
         default:
             return false;
         }
@@ -304,8 +300,10 @@
         this.preferences.destroy();
         this.preferences = null;
 
-        this.menu_button.destroy();
-        this.menu_button = null;
+        if (this.menu_button) {
+            this.menu_button.destroy();
+            this.menu_button = null;
+        }
 
         this.dragboard.destroy();
         this.dragboard = null;
