@@ -24,13 +24,7 @@
  */
 
 
-function Workspace (workspaceState) {
-
-    Workspace.prototype._updateAddTabButton = function () {
-        if (this.addTabButton) {
-            this.addTabButton.setDisabled(!this.isAllowed('add_tab'));
-        }
-    }
+function Workspace(workspaceState, resources) {
 
     // ****************
     // CALLBACK METHODS
@@ -48,17 +42,16 @@ function Workspace (workspaceState) {
         // Show a user friend alert
         var layoutManager = LayoutManagerFactory.getInstance();
         var msg = gettext('Error loading workspace. Please, change active workspace or create a new one.');
-        layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
 
         // Clean current status
         this.varmanager = null;
         this.contextManager = null;
         this.wiring = null;
-        this.wiringInterface = null;
 
         // Failsafe workspace status
         layoutManager.currentViewType = "dragboard"; // workaround
-        this.preferences = PreferencesManagerFactory.getInstance().buildPreferences('workspace', {}, this)
+        this.preferences = Wirecloud.PreferenceManager.buildPreferences('workspace', {}, this)
 
         var initialTab = {
             'id': 0,
@@ -69,12 +62,12 @@ function Workspace (workspaceState) {
             'preferences': {}
         };
 
-        this.workspaceGlobalInfo = {
-                                       'tabs': [
-                                         initialTab
-                                       ]
-                                   };
-        this.tabInstances = new Hash();
+        this.workspaceState = {
+            'tabs': [
+                initialTab
+            ]
+        };
+        this.tabInstances = {};
         // TODO
         this.notebook.clear()
         this.tabInstances[0] = this.notebook.createTab({'tab_constructor': Tab, 'tab_info': initialTab, 'workspace': this});
@@ -82,12 +75,10 @@ function Workspace (workspaceState) {
         this.loaded = true;
 
         layoutManager.logStep('');
-        OpManagerFactory.getInstance().continueLoadingGlobalModules(Modules.prototype.ACTIVE_WORKSPACE);
     };
 
-    // Not like the remaining methods. This is a callback function to process AJAX requests, so must be public.
-    var loadWorkspace = function (transport) {
-        var layoutManager, params, param, preferencesWindow, preferenceValues, iwidgets;
+    var loadWorkspace = function () {
+        var layoutManager, params, preferenceValues, iwidgets;
 
         layoutManager = LayoutManagerFactory.getInstance();
         layoutManager.logStep('');
@@ -95,36 +86,16 @@ function Workspace (workspaceState) {
 
         try {
             // JSON-coded iWidget-variable mapping
-            this.workspaceGlobalInfo = JSON.parse(transport.responseText);
-
             // Load workspace preferences
-            params = this.workspaceGlobalInfo.empty_params;
-            preferenceValues = this.workspaceGlobalInfo['preferences'];
-            this.preferences = PreferencesManagerFactory.getInstance().buildPreferences('workspace', preferenceValues, this, params);
+            params = this.workspaceState.empty_params;
+            preferenceValues = this.workspaceState.preferences;
+            this.preferences = Wirecloud.PreferenceManager.buildPreferences('workspace', preferenceValues, this, params);
 
-            // Check if the workspace needs to ask some values before loading this workspace
-            if (this.workspaceGlobalInfo.empty_params.length > 0) {
-                preferenceValues = {};
-                for (i = 0; i < params.length; i += 1) {
-                    param = params[i];
-                    if (this.workspaceGlobalInfo.preferences[param] != null) {
-                        preferenceValues[param] = this.workspaceGlobalInfo.preferences[param];
-                    }
-                }
-
-                this.preferences.addCommitHandler(function() {
-                    setTimeout(function() {
-                        OpManagerFactory.getInstance().changeActiveWorkspace(this);
-                    }.bind(this), 0);
-                }.bind(this));
-                preferencesWindow = this.getPreferencesWindow();
-                preferencesWindow.setCancelable(false);
-                preferencesWindow.show();
-                return;
-            }
+            this.restricted = !this.owned /* TODO */ || Wirecloud.contextManager.get('mode') === 'embedded';
+            this.removable = !this.restricted && this.workspaceState.removable;
 
             // Load workspace tabs
-            var tabs = this.workspaceGlobalInfo['tabs'];
+            var tabs = this.workspaceState.tabs;
             var visibleTabId = null;
             var loading_tab = this.notebook.createTab({'closeable': false});
 
@@ -134,7 +105,7 @@ function Workspace (workspaceState) {
                 for (var i = 0; i < tabs.length; i++) {
                     var tab = tabs[i];
                     var tabInstance = this.notebook.createTab({'tab_constructor': Tab, 'tab_info': tab, 'workspace': this});
-                    this.tabInstances.set(tab.id, tabInstance);
+                    this.tabInstances[tab.id] = tabInstance;
 
                     if (tab.visible) {
                         visibleTabId = tab.id;
@@ -144,28 +115,27 @@ function Workspace (workspaceState) {
 
             this.varManager = new VarManager(this);
 
-            this.contextManager = new Wirecloud.ContextManager(this, this.workspaceGlobalInfo.context);
+            this.contextManager = new Wirecloud.ContextManager(this, this.workspaceState.context);
             this.wiring = new Wirecloud.Wiring(this);
             iwidgets = this.getIWidgets();
             for (i = 0; i < iwidgets.length; i += 1) {
+                iwidgets[i].internal_iwidget.addEventListener('removed', this._iwidget_removed);
                 this.events.iwidgetadded.dispatch(this, iwidgets[i].internal_iwidget);
             }
 
+            this.valid = true;
+
             // FIXME
             LayoutManagerFactory.getInstance().mainLayout.repaint();
             LayoutManagerFactory.getInstance().header._notifyWorkspaceLoaded(this);
             // END FIXME
 
-            this.restricted = !this.isOwned() && this.isShared();
-            this.removable = !this.restricted && this.workspaceGlobalInfo.removable;
-            this.valid = true;
-
-            if (this.initial_tab_id && this.tabInstances.get(this.initial_tab_id)) {
+            if (this.initial_tab_id && this.tabInstances[this.initial_tab_id]) {
                 visibleTabId = this.initial_tab_id;
             }
 
-            this.wiring.load(this.workspaceGlobalInfo.wiring);
-            this.notebook.goToTab(this.tabInstances.get(visibleTabId));
+            this.wiring.load(this.workspaceState.wiring);
+            this.notebook.goToTab(this.tabInstances[visibleTabId]);
             loading_tab.close();
 
         } catch (error) {
@@ -178,14 +148,13 @@ function Workspace (workspaceState) {
         this.loaded = true;
 
         layoutManager.logStep('');
-        OpManagerFactory.getInstance().continueLoadingGlobalModules(Modules.prototype.ACTIVE_WORKSPACE);
-        Wirecloud.GlobalLogManager.log(gettext('workspace loaded'), Constants.Logging.INFO_MSG);
+        Wirecloud.GlobalLogManager.log(gettext('Workspace loaded'), Wirecloud.constants.LOGGING.INFO_MSG);
 
         // tutorial layer for empty workspaces
         this.emptyWorkspaceInfoBox = document.createElement('div');
-        this.emptyWorkspaceInfoBox.addClassName('emptyWorkspaceInfoBox');
+        this.emptyWorkspaceInfoBox.className = 'emptyWorkspaceInfoBox';
         var subBox = document.createElement('div');
-        subBox.addClassName('alert alert-info alert-block');
+        subBox.className = 'alert alert-info alert-block';
 
         // Title
         var pTitle = document.createElement('h4');
@@ -202,7 +171,7 @@ function Workspace (workspaceState) {
         this.emptyWorkspaceInfoBox.appendChild(subBox);
         this.notebook.getTabByIndex(0).wrapperElement.appendChild(this.emptyWorkspaceInfoBox);
         if (this.getIWidgets().length !== 0) {
-            this.emptyWorkspaceInfoBox.addClassName('hidden');
+            this.emptyWorkspaceInfoBox.classList.add('hidden');
         }
     }
 
@@ -211,23 +180,19 @@ function Workspace (workspaceState) {
     }
 
     var renameError = function(transport, e) {
-        var layoutManager, msg;
-
-        layoutManager = LayoutManagerFactory.getInstance();
-
-        msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error renaming workspace: %(errorMsg)s."), transport, e);
-        layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error renaming workspace: %(errorMsg)s."), transport, e);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
     };
 
     var deleteSuccess = function (transport) {
-        OpManagerFactory.getInstance().removeWorkspace(this.workspaceState.id);
-        LayoutManagerFactory.getInstance().logSubTask(gettext('Workspace renamed successfully'));
+        OpManagerFactory.getInstance().removeWorkspace(this);
+        LayoutManagerFactory.getInstance().logSubTask(gettext('Workspace removed successfully'));
         LayoutManagerFactory.getInstance().logStep('');
     };
 
     var deleteError = function(transport, e) {
         var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error removing workspace, changes will not be saved: %(errorMsg)s."), transport, e);
-        LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
 
         LayoutManagerFactory.getInstance()._notifyPlatformReady();
     };
@@ -271,7 +236,8 @@ function Workspace (workspaceState) {
         var data = JSON.parse(response);
         //update the new wsInfo
         opManager = OpManagerFactory.getInstance();
-        opManager.changeActiveWorkspace(opManager.workspaceInstances.get(data.merged_workspace_id));
+        var workspace = new Workspace(opManager.workspaceInstances[data.merged_workspace_id]);
+        Wirecloud.changeActiveWorkspace(workspace);
         LayoutManagerFactory.getInstance().hideCover();
     }
 
@@ -284,7 +250,7 @@ function Workspace (workspaceState) {
         layoutManager.logStep('');
         layoutManager._notifyPlatformReady();
 
-        layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
     }
 
     //**** TAB CALLBACK*****
@@ -298,7 +264,7 @@ function Workspace (workspaceState) {
         tabInfo.preferences = {};
 
         var newTab = this.notebook.createTab({'tab_constructor': Tab, 'tab_info': tabInfo, 'workspace': this});
-        this.tabInstances.set(tabInfo.id, newTab);
+        this.tabInstances[tabInfo.id] = newTab;
 
         layoutManager.logSubTask(gettext('Tab added successfully'));
         layoutManager.logStep('');
@@ -308,10 +274,22 @@ function Workspace (workspaceState) {
         Wirecloud.GlobalLogManager.formatAndLog(gettext("Error creating a tab: %(errorMsg)s."), transport, e);
     };
 
+    var iwidget_removed = function iwidget_removed(iwidget) {
+        this.events.iwidgetremoved.dispatch(this, iwidget);
+
+        // emptyWorkspaceInfoBox
+        if (this.getIWidgets().length == 0) {
+            this.emptyWorkspaceInfoBox.classList.remove('hidden');
+        }
+    };
+
     // ****************
     // PUBLIC METHODS
     // ****************
 
+    Workspace.prototype.addInstance = function addInstance(widget, options) {
+        this.getVisibleTab().getDragboard().addInstance(widget, options);
+    };
 
     Workspace.prototype.checkForWidgetUpdates = function() {
         var i, iwidgets;
@@ -322,14 +300,6 @@ function Workspace (workspaceState) {
         }
     };
 
-    Workspace.prototype.iwidgetUnloaded = function(iwidgetId) {
-        var iwidget = this.getIWidget(iwidgetId);
-        if (iwidget == null)
-            return;
-
-        iwidget._notifyUnloaded();
-    }
-
     Workspace.prototype.sendBufferedVars = function (async) {
         if (this.varManager) this.varManager.sendBufferedVars(async);
     }
@@ -341,7 +311,7 @@ function Workspace (workspaceState) {
     Workspace.prototype.rename = function rename(name) {
         var layoutManager, workspaceUrl, msg = null;
 
-        name = name.strip()
+        name = name.trim();
 
         if (name === "") {
             msg = gettext("Invalid workspace name");
@@ -360,25 +330,26 @@ function Workspace (workspaceState) {
         msg = interpolate(msg, {workspacename: this.workspaceState.name, newname: name}, true);
         layoutManager.logSubTask(msg);
 
-        workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({workspace_id: this.workspaceState.id});
+        workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({workspace_id: this.id});
         Wirecloud.io.makeRequest(workspaceUrl, {
             method: 'POST',
             contentType: 'application/json',
+            requestHeaders: {'Accept': 'application/json'},
             postBody: JSON.stringify({name: name}),
             onSuccess: function () {
                 var state, layoutManager = LayoutManagerFactory.getInstance();
 
                 this.workspaceState.name = name;
                 this.contextManager.modify({'name': name});
-                layoutManager.header.refresh();
                 state = {
                     workspace_creator: this.workspaceState.creator,
                     workspace_name: name,
                     view: "workspace",
-                    tab: HistoryManager.getCurrentState().tab
+                    tab: Wirecloud.HistoryManager.getCurrentState().tab
                 };
-                HistoryManager.pushState(state);
+                Wirecloud.HistoryManager.replaceState(state);
 
+                layoutManager.header.refresh();
                 layoutManager.logSubTask(gettext('Workspace renamed successfully'));
                 layoutManager.logStep('');
             }.bind(this),
@@ -399,9 +370,10 @@ function Workspace (workspaceState) {
         msg = interpolate(msg, {workspacename: this.workspaceState.name}, true);
         layoutManager.logSubTask(msg);
 
-        workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({workspace_id: this.workspaceState.id});
+        workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({workspace_id: this.id});
         Wirecloud.io.makeRequest(workspaceUrl, {
             method: 'DELETE',
+            requestHeaders: {'Accept': 'application/json'},
             onSuccess: deleteSuccess.bind(this),
             onFailure: deleteError,
             onException: deleteError
@@ -412,49 +384,73 @@ function Workspace (workspaceState) {
         return this.workspaceState.name;
     }
 
-
-    Workspace.prototype.getId = function () {
-        return this.workspaceState.id;
-    }
-
     Workspace.prototype.getVarManager = function () {
         return this.varManager;
     }
 
-    Workspace.prototype.downloadWorkspaceInfo = function (initial_tab) {
+    Workspace.prototype.initGUI = function initGUI() {
+
         // TODO
-        this.addTabButton = new StyledElements.StyledButton({
-            'class': 'icon-add-tab',
-            'plain': true,
-            'title': gettext('Add a new tab')
-        });
+        if (this.isAllowed('add_tab')) {
+            this.addTabButton = new StyledElements.StyledButton({
+                'class': 'icon-add-tab',
+                'plain': true,
+                'title': gettext('Add a new tab')
+            });
 
-        this.poweredByWirecloudButton = new StyledElements.StyledButton({
-            'class': 'powered-by-wirecloud'
-        });
+            this.notebook.addButton(this.addTabButton);
+            this.addTabButton.addEventListener('click', this.addTab.bind(this));
+        }
 
-        this.notebook = new StyledElements.StyledNotebook({'class': 'workspace'});
-        this.notebook.addButton(this.addTabButton);
-        this.addTabButton.addEventListener('click', this.addTab.bind(this));
-        this.notebook.addButton(this.poweredByWirecloudButton);
-        this.poweredByWirecloudButton.addEventListener('click', function () {window.open('http://conwet.fi.upm.es/wirecloud/', '_blank')});
-        LayoutManagerFactory.getInstance().viewsByName['workspace'].clear();
-        LayoutManagerFactory.getInstance().viewsByName['workspace'].appendChild(this.notebook);
+        if (Wirecloud.contextManager.get('mode') === 'embedded' && Wirecloud.Utils.isFullscreenSupported()) {
+            this.fullscreenButton = new StyledElements.StyledButton({
+                'class': 'icon-resize-full',
+                'plain': true
+            });
+            this.notebook.addButton(this.fullscreenButton);
+            Wirecloud.Utils.onFullscreenChange(this.notebook, function () {
+                this.fullscreenButton.removeClassName('icon-resize-full');
+                this.fullscreenButton.removeClassName('icon-resize-small');
+                if (this.notebook.fullscreen) {
+                    this.fullscreenButton.addClassName('icon-resize-small');
+                    this.notebook.addClassName('fullscreen');
+                } else {
+                    this.fullscreenButton.addClassName('icon-resize-full');
+                    this.notebook.removeClassName('fullscreen');
+                }
+            }.bind(this));
+            this.fullscreenButton.addEventListener('click', function () {
+                if (this.notebook.fullscreen) {
+                    this.notebook.exitFullscreen();
+                } else {
+                    this.notebook.requestFullscreen();
+                }
+            }.bind(this));
+        }
 
-        LayoutManagerFactory.getInstance().logSubTask(gettext("Downloading workspace data"), 1);
-        this.initial_tab_id = initial_tab;
-        var workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({'workspace_id': this.workspaceState.id});
-        Wirecloud.io.makeRequest(workspaceUrl, {
-            method: 'GET',
-            onSuccess: loadWorkspace.bind(this),
-            onFailure: onError.bind(this)
-        });
+        if (Wirecloud.contextManager.get('mode') === 'embedded') {
+            this.seeOnWirecloudButton = new StyledElements.StyledButton({
+                'class': 'powered-by-wirecloud'
+            });
+            this.notebook.addButton(this.seeOnWirecloudButton);
+            this.seeOnWirecloudButton.addEventListener('click', function () {
+                var url = Wirecloud.URLs.WORKSPACE_VIEW.evaluate({owner: encodeURIComponent(this.workspaceState.creator), name: encodeURIComponent(this.workspaceState.name)});
+                window.open(url, '_blank')
+            }.bind(this));
+        } else {
+            this.poweredByWirecloudButton = new StyledElements.StyledButton({
+                'class': 'powered-by-wirecloud'
+            });
+            this.notebook.addButton(this.poweredByWirecloudButton);
+            this.poweredByWirecloudButton.addEventListener('click', function () {window.open('http://conwet.fi.upm.es/wirecloud/', '_blank')});
+        }
+
+        LayoutManagerFactory.getInstance().viewsByName.workspace.repaint();
     };
 
     Workspace.prototype.getIWidget = function(iwidgetId) {
-        var i, tab_keys = this.tabInstances.keys();
-        for (i = 0; i < tab_keys.length; i += 1) {
-            var tab = this.tabInstances.get(tab_keys[i]);
+        for (var key in this.tabInstances) {
+            var tab = this.tabInstances[key];
             var iwidget = tab.getDragboard().getIWidget(iwidgetId);
 
             if (iwidget) {
@@ -479,7 +475,7 @@ function Workspace (workspaceState) {
     }
 
     Workspace.prototype.getTab = function(tabId) {
-        return this.tabInstances.get(tabId);
+        return this.tabInstances[tabId];
     }
 
     Workspace.prototype.setTab = function(tab) {
@@ -500,10 +496,9 @@ function Workspace (workspaceState) {
         return this.notebook.getVisibleTab();
     }
 
-    Workspace.prototype.tabExists = function(tabName){
-        var tabValues = this.tabInstances.values();
-        for (var i = 0; i < tabValues.length; i++) {
-            if (tabValues[i].tabInfo.name === tabName) {
+    Workspace.prototype.tabExists = function (tabName) {
+        for (var key in this.tabInstances) {
+            if (this.tabInstances[key].tabInfo.name === tabName) {
                 return true;
             }
         }
@@ -523,18 +518,19 @@ function Workspace (workspaceState) {
         msg = interpolate(msg, {workspacename: this.workspaceState.name}, true);
         layoutManager.logSubTask(msg);
 
-        counter = this.tabInstances.keys().length + 1;
+        counter = Object.keys(this.tabInstances).length + 1;
         prefixName = gettext("Tab");
         tabName = prefixName + " " + counter.toString();
         //check if there is another tab with the same name
         while (this.tabExists(tabName)) {
             tabName = prefixName + " " + (counter++).toString();
         }
-        url = Wirecloud.URLs.TAB_COLLECTION.evaluate({workspace_id: this.workspaceState.id});
+        url = Wirecloud.URLs.TAB_COLLECTION.evaluate({workspace_id: this.id});
         Wirecloud.io.makeRequest(url, {
             method: 'POST',
             contentType: 'application/json',
-            postBody: Object.toJSON({name: tabName}),
+            requestHeaders: {'Accept': 'application/json'},
+            postBody: JSON.stringify({name: tabName}),
             onSuccess: createTabSuccess.bind(this),
             onFailure: createTabError,
             onException: createTabError,
@@ -547,7 +543,7 @@ function Workspace (workspaceState) {
     //It returns if the tab can be removed and shows an error window if it isn't possible
     Workspace.prototype.removeTab = function(tab) {
         var msg = null;
-        if (this.tabInstances.keys().length <= 1) {
+        if (Object.keys(this.tabInstances).length <= 1) {
             msg = gettext("there must be one tab at least");
             msg = interpolate(gettext("Error removing tab: %(errorMsg)s."), {
                 errorMsg: msg
@@ -561,8 +557,7 @@ function Workspace (workspaceState) {
 
         if (msg) { //It cannot be deleted
             Wirecloud.GlobalLogManager.log(msg);
-            //LayoutManagerFactory.getInstance().hideCover();
-            LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+            (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
             return false;
         }
 
@@ -575,9 +570,9 @@ function Workspace (workspaceState) {
         if (!this.valid)
             return;
 
-        var tab = this.tabInstances.get(tabId);
+        var tab = this.tabInstances[tabId];
 
-        this.tabInstances.unset(tabId);
+        delete this.tabInstances[tabId];
         tab.close();
         tab.destroy();
     };
@@ -589,21 +584,11 @@ function Workspace (workspaceState) {
 
         this.loaded = false;
 
-        // Unload Wiring Interface
-        // TODO Wiring Interface should be shared between Workspaces
-        if (this.wiringInterface !== null) {
-            this.wiringInterface.saveWiring();
-        }
-
-        //layoutManager.unloadCurrentView();
-
         this.sendBufferedVars(false);
 
         // After that, tab info is managed
-        var tabKeys = this.tabInstances.keys();
-
-        for (var i=0; i<tabKeys.length; i++) {
-            this.unloadTab(tabKeys[i]);
+        for (var key in this.tabInstances) {
+            this.unloadTab(key);
         }
 
         if (this.pref_window_menu != null) {
@@ -616,6 +601,8 @@ function Workspace (workspaceState) {
             this.preferences = null;
         }
 
+        this.varManager = null;
+
         if (this.wiring !== null) {
             this.wiring.destroy();
             this.wiring = null;
@@ -624,15 +611,15 @@ function Workspace (workspaceState) {
         this.contextManager = null;
 
         layoutManager.logStep('');
-        Wirecloud.GlobalLogManager.log(gettext('workspace unloaded'), Constants.Logging.INFO_MSG);
+        Wirecloud.GlobalLogManager.log(gettext('workspace unloaded'), Wirecloud.constants.LOGGING.INFO_MSG);
         Wirecloud.GlobalLogManager.newCycle();
     }
 
     Workspace.prototype.addIWidget = function(tab, iwidget, iwidgetJSON, options) {
         // emptyWorkspaceInfoBox
-        this.emptyWorkspaceInfoBox.addClassName('hidden');
+        this.emptyWorkspaceInfoBox.classList.add('hidden');
 
-        this.varManager.addInstance(iwidget, iwidgetJSON, tab);
+        iwidget.internal_iwidget.addEventListener('removed', this._iwidget_removed);
         this.events.iwidgetadded.dispatch(this, iwidget.internal_iwidget);
 
         options.setDefaultValues.call(this, iwidget.id);
@@ -640,30 +627,10 @@ function Workspace (workspaceState) {
         iwidget.paint();
     };
 
-    Workspace.prototype.removeIWidget = function(iWidgetId, orderFromServer) {
-
-        var iwidget = this.getIWidget(iWidgetId);
-        if (iwidget == null) {
-            throw new TypeError();
-        }
-
-        var dragboard = iwidget.layout.dragboard;
-        dragboard.removeInstance(iWidgetId, orderFromServer); // TODO split into hideInstance and removeInstance
-        this.events.iwidgetremoved.dispatch(this, iwidget.internal_iwidget);
-
-        iwidget.destroy();
-
-        // emptyWorkspaceInfoBox
-        if (this.getIWidgets().length == 0) {
-            this.emptyWorkspaceInfoBox.removeClassName('hidden');
-        }
-    }
-
     Workspace.prototype.getIWidgets = function() {
         var iWidgets = [];
-        var keys = this.tabInstances.keys();
-        for (var i = 0; i < keys.length; i++) {
-            iWidgets = iWidgets.concat(this.tabInstances.get(keys[i]).getDragboard().getIWidgets());
+        for (var keys in this.tabInstances) {
+            iWidgets = iWidgets.concat(this.tabInstances[keys].getDragboard().getIWidgets());
         }
 
         return iWidgets;
@@ -692,9 +659,10 @@ function Workspace (workspaceState) {
         }
         delete data.image;
         payload.append('json', JSON.stringify(data));
-        var workspaceUrl = Wirecloud.URLs.WORKSPACE_PUBLISH.evaluate({workspace_id: this.workspaceState.id});
+        var workspaceUrl = Wirecloud.URLs.WORKSPACE_PUBLISH.evaluate({workspace_id: this.id});
         Wirecloud.io.makeRequest(workspaceUrl, {
             method: 'POST',
+            requestHeaders: {'Accept': 'application/json'},
             postBody: payload,
             context: {workspace: this, params: data, options: options},
             onSuccess: publishSuccess.bind(null, options),
@@ -716,7 +684,7 @@ function Workspace (workspaceState) {
         msg = interpolate(msg, {srcworkspace: workspace.name, dstworkspace: this.getName()}, true);
         layoutManager.logSubTask(msg);
 
-        workspaceUrl = Wirecloud.URLs.WORKSPACE_MERGE.evaluate({to_ws_id: this.workspaceState.id});
+        workspaceUrl = Wirecloud.URLs.WORKSPACE_MERGE.evaluate({to_ws_id: this.id});
         Wirecloud.io.markeRequest(workspaceUrl, {
             method: 'POST',
             contentType: 'application/json',
@@ -731,11 +699,6 @@ function Workspace (workspaceState) {
         return this.workspaceState['shared'];
     };
 
-    // Checks if the current user is the creator of this workspace
-    Workspace.prototype.isOwned = function() {
-        return this.workspaceState['owned'];
-    };
-
     /**
      * Checks when an action, defined by a basic policy, can be performed.
      */
@@ -747,7 +710,7 @@ function Workspace (workspaceState) {
      * Checks if an action can be performed in this workspace by current user.
      */
     Workspace.prototype.isAllowed = function (action) {
-        var nworkspaces;
+        var username, workspaces, nworkspaces;
 
         if (action !== "remove" && (!this.valid || this.restricted)) {
             return false;
@@ -755,14 +718,27 @@ function Workspace (workspaceState) {
 
         switch (action) {
         case "remove":
-            nworkspaces = OpManagerFactory.getInstance().workspaceInstances.keys().length;
-            return /* opManager.isAllow('add_remove_workspaces') && */ (nworkspaces > 1) && this.removable;
+            //opManager = OpManagerFactory.getInstance();
+            username = Wirecloud.contextManager.get('username');
+            workspaces = OpManagerFactory.getInstance().workspacesByUserAndName[username];
+            if (workspaces != null) {
+                nworkspaces = Object.keys(workspaces).length;
+            } else {
+                nworkspaces = 0;
+            }
+            return /* opManager.isAllow('add_remove_workspaces') && */ this.removable && (nworkspaces > 1);
         case "merge_workspaces":
             return this._isAllowed('add_remove_iwidgets') || this._isAllowed('merge_workspaces');
         case "catalogue_view_widgets":
             return this._isAllowed('add_remove_iwidgets');
         case "catalogue_view_mashups":
-            return this.isAllowed('add_remove_workspaces') || this.isAllowed('merge_workspaces');
+            return this.isAllowed('add_remove_workspaces') || this._isAllowed('merge_workspaces');
+        case "update_preferences":
+            return this.removable && this._isAllowed('change_workspace_preferences');
+        case "rename":
+            return this.removable && this._isAllowed('rename_workspaces');
+        case "add_tab":
+            return this.removable;
         default:
             return this._isAllowed(action);
         }
@@ -772,29 +748,38 @@ function Workspace (workspaceState) {
     //  CONSTRUCTOR
     // *****************
 
+    Object.defineProperty(this, 'id', {value: workspaceState.id});
+    Object.defineProperty(this, 'resources', {value: resources});
+    Object.defineProperty(this, 'owned', {value: workspaceState.owned});
+    Object.defineProperty(this, '_iwidget_removed', {value: iwidget_removed.bind(this)});
     this.workspaceState = workspaceState;
-    this.workspaceGlobal = null;
-    this.wiringInterface = null;
     this.varManager = null;
-    this.tabInstances = new Hash();
+    this.tabInstances = {};
     this.highlightTimeouts = {};
     this.wiring = null;
     this.varManager = null;
     this.contextManager = null;
     this.loaded = false;
-    this.wiringLayer = null;
-    this.valid=false;
+    this.valid = false;
 
     StyledElements.ObjectWithEvents.call(this, ['iwidgetadded', 'iwidgetremoved']);
 
+    this.notebook = new StyledElements.StyledNotebook({'class': 'workspace'});
+    LayoutManagerFactory.getInstance().viewsByName['workspace'].clear();
+    LayoutManagerFactory.getInstance().viewsByName['workspace'].appendChild(this.notebook);
+
+    loadWorkspace.call(this);
+    this.initGUI();
+
     /*
      * OPERATIONS
      */
     this.markAsActive = function () {
-        var workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({'workspace_id': this.workspaceState.id});
+        var workspaceUrl = Wirecloud.URLs.WORKSPACE_ENTRY.evaluate({'workspace_id': this.id});
         Wirecloud.io.makeRequest(workspaceUrl, {
             method: 'POST',
             contentType: 'application/json',
+            requestHeaders: {'Accept': 'application/json'},
             postBody: JSON.stringify({active: true}),
             onSuccess: this.markAsActiveSuccess.bind(this),
             onFailure: this.markAsActiveError.bind(this)
@@ -802,7 +787,6 @@ function Workspace (workspaceState) {
     }.bind(this);
 
     this.markAsActiveSuccess = function() {
-        this.workspaceGlobalInfo.active = true;
         this.workspaceState.active = true;
         if (this.activeEntryId != null) {
             this.confMenu.removeOption(this.activeEntryId);
@@ -836,20 +820,20 @@ Workspace.prototype.highlightTab = function(tab) {
     var tabElement;
 
     if (typeof tab === 'number') {
-        tab = this.tabInstances.get(tab);
+        tab = this.tabInstances[tab];
     }
 
     if (!(tab instanceof Tab)) {
         throw new TypeError();
     }
 
-    tabElement = tab.tabHTMLElement;
-    tabElement.addClassName("selected");
+    tabElement = tab.tabElement;
+    tabElement.classList.add("highlight");
     if (tab.tabInfo.id in this.highlightTimeouts) {
         clearTimeout(this.highlightTimeouts[tab.tabInfo.id]);
     }
     this.highlightTimeouts[tab.tabInfo.id] = setTimeout(function() {
-        tabElement.removeClassName("selected");
+        tabElement.classList.remove("highlight");
         delete this.highlightTimeouts[tab.tabInfo.id];
     }.bind(this), 10000);
 };
