@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2012-2013 Universidad Politécnica de Madrid
+ *     Copyright 2012-2014 (c) CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global gettext, OpManagerFactory, StyledElements, Wirecloud, WorkspaceItems, WorkspaceListItems*/
+/*global gettext, StyledElements, Wirecloud, WorkspaceItems*/
 
 (function () {
 
@@ -30,50 +30,37 @@
         StyledElements.Alternative.call(this, id, options);
 
         this.wsMenu = new StyledElements.PopupMenu();
-        this.wsMenu.append(new WorkspaceListItems(function (workspace) {
-            OpManagerFactory.getInstance().changeActiveWorkspace(workspace);
+        this.wsMenu.append(new Wirecloud.ui.WorkspaceListItems(function (context, workspace) {
+            Wirecloud.changeActiveWorkspace(workspace);
         }));
         this.wsMenu.appendSeparator();
-        this.wsMenu.append(new WorkspaceItems());
-
-        this.wsMenu.append(new StyledElements.MenuItem(gettext('New workspace'), function () {
-            this.createWorkspaceWindow.show();
-        }.bind(this)));
-
-        this.wsMenu.append(new StyledElements.MenuItem(gettext('Upload to local catalogue'), function () {
-            LayoutManagerFactory.getInstance().viewsByName.marketplace.waitMarketListReady(function () {
-                var window = new Wirecloud.ui.PublishWorkspaceWindowMenu(OpManagerFactory.getInstance().activeWorkspace);
-                window.show();
-            });
-        }.bind(this)));
+        this.wsMenu.append(new WorkspaceItems(this));
     };
     WorkspaceView.prototype = new StyledElements.Alternative();
 
     WorkspaceView.prototype.view_name = 'workspace';
 
     WorkspaceView.prototype.buildStateData = function buildStateData() {
-        return EzWebExt.merge(HistoryManager.getCurrentState(), {
+        return Wirecloud.Utils.merge(Wirecloud.HistoryManager.getCurrentState(), {
             view: 'workspace'
         });
     };
 
     WorkspaceView.prototype.getBreadcrum = function getBreadcrum() {
-        var workspace, workspace_name, entries;
+        var workspace_name, entries, current_state, menu, context;
 
-        workspace = OpManagerFactory.getInstance().activeWorkspace;
-        if (workspace != null) {
-            // TODO
-            // Moved here to ensure the initial theme has been loaded
-            if (this.createWorkspaceWindow == null) {
-                this.createWorkspaceWindow = new Wirecloud.ui.NewWorkspaceWindowMenu();
+        current_state = Wirecloud.HistoryManager.getCurrentState();
+        if ('workspace_creator' in current_state) {
+            context = Wirecloud.contextManager;
+            if (context && context.get('username') !== 'anonymous') {
+                menu = this.wsMenu;
             }
-
             entries = [
                 {
-                    'label': workspace.workspaceGlobalInfo.creator
+                    'label': current_state.workspace_creator
                 }, {
-                    'label': workspace.getName(),
-                    'menu': this.wsMenu
+                    'label': current_state.workspace_name,
+                    'menu': menu
                 }
             ];
         } else {
