@@ -1,4 +1,25 @@
-/*global Constants, EzWebExt, gettext, LayoutManagerFactory, Wirecloud*/
+/*
+ *     Copyright 2013 (c) CoNWeT Lab., Universidad Politécnica de Madrid
+ *
+ *     This file is part of Wirecloud Platform.
+ *
+ *     Wirecloud Platform is free software: you can redistribute it and/or
+ *     modify it under the terms of the GNU Affero General Public License as
+ *     published by the Free Software Foundation, either version 3 of the
+ *     License, or (at your option) any later version.
+ *
+ *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
+ *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
+ *     License for more details.
+ *
+ *     You should have received a copy of the GNU Affero General Public License
+ *     along with Wirecloud Platform.  If not, see
+ *     <http://www.gnu.org/licenses/>.
+ *
+ */
+
+/*global gettext, LayoutManagerFactory, Wirecloud*/
 
 (function () {
 
@@ -73,7 +94,7 @@
             }
             return result;
         });
-        data.resource = this.resource.getURI();
+        data.resource = this.resource.uri;
 
         var layoutManager;
 
@@ -84,14 +105,15 @@
         Wirecloud.io.makeRequest(url, {
             method: 'POST',
             contentType: 'application/json',
-            postBody: Object.toJSON(data),
+            requestHeaders: {'Accept': 'application/json'},
+            postBody: JSON.stringify(data),
             onSuccess: function () {
                 layoutManager.logSubTask(gettext('Resource published successfully'));
                 layoutManager.getInstance().logStep('');
             },
             onFailure: function (transport) {
                 var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error publishing resource: %(errorMsg)s."), transport, null);
-                layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+                (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
             },
             onComplete: function () {
                 LayoutManagerFactory.getInstance()._notifyPlatformReady();
