@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global $, gettext, LayoutManagerFactory, OpManagerFactory, StyledElements, Wirecloud*/
+/*global gettext, LayoutManagerFactory, OpManagerFactory, StyledElements, Wirecloud*/
 
 (function () {
 
@@ -32,8 +32,8 @@
     var WirecloudHeader = function WirecloudHeader() {
         var menu_wrapper;
 
-        this.wrapperElement = $('wirecloud_header');
-        this.breadcrum = $('wirecloud_breadcrum');
+        this.wrapperElement = document.getElementById('wirecloud_header');
+        this.breadcrum = document.getElementById('wirecloud_breadcrum');
 
         this.currentView = null;
         this.currentMenu = null;
@@ -81,30 +81,48 @@
     };
 
     WirecloudHeader.prototype._initUserMenu = function _initUserMenu() {
-        var user_menu, wrapper;
+        var user_name, user_menu, wrapper, login_button;
 
-        wrapper = document.createElement('div');
-        wrapper.className = 'user_menu_wrapper';
-        this.menu.appendChild(wrapper);
+        user_name = Wirecloud.contextManager.get('username');
+        if (user_name === 'anonymous') {
+            this.menu.innerHTML = '';
 
-        this.user_button = new StyledElements.PopupButton({
-            'class': 'btn-success',
-            'text': OpManagerFactory.getInstance().contextManager.get('username')
-        });
-        this.user_button.insertInto(wrapper);
+            wrapper = document.createElement('div');
+            wrapper.className = 'user_menu_wrapper';
+            this.menu.appendChild(wrapper);
+
+            login_button = new StyledElements.StyledButton({
+                text: gettext('Sign in')
+            });
+            login_button.addEventListener('click', function () {
+                window.location = Wirecloud.URLs.LOGIN_VIEW + '?next=' + encodeURIComponent(window.location.pathname + window.location.search + window.location.hash);
+            });
+            login_button.insertInto(wrapper);
+        } else {
+
+            wrapper = document.createElement('div');
+            wrapper.className = 'user_menu_wrapper';
+            this.menu.appendChild(wrapper);
+
+            this.user_button = new StyledElements.PopupButton({
+                'class': 'btn-success user',
+                'text': user_name
+            });
+            this.user_button.insertInto(wrapper);
 
 
-        user_menu = this.user_button.getPopupMenu();
-        user_menu.append(new StyledElements.MenuItem(gettext('Settings'), OpManagerFactory.getInstance().showPlatformPreferences));
+            user_menu = this.user_button.getPopupMenu();
+            user_menu.append(new StyledElements.MenuItem(gettext('Settings'), OpManagerFactory.getInstance().showPlatformPreferences));
 
-        if (OpManagerFactory.getInstance().contextManager.get('isstaff') === true && 'DJANGO_ADMIN' in Wirecloud.URLs) {
-            user_menu.append(new StyledElements.MenuItem(gettext('DJango Admin panel'), function () {
-                window.open(Wirecloud.URLs.DJANGO_ADMIN, '_blank');
-            }));
+            if (Wirecloud.contextManager.get('isstaff') === true && 'DJANGO_ADMIN' in Wirecloud.URLs) {
+                user_menu.append(new StyledElements.MenuItem(gettext('DJango Admin panel'), function () {
+                    window.open(Wirecloud.URLs.DJANGO_ADMIN, '_blank');
+                }));
+            }
+            user_menu.append(new Wirecloud.ui.TutorialSubMenu());
+
+            user_menu.append(new StyledElements.MenuItem(gettext('Sign out'), OpManagerFactory.getInstance().logout));
         }
-        user_menu.append(new Wirecloud.ui.TutorialSubMenu());
-
-        user_menu.append(new StyledElements.MenuItem(gettext('Sign out'), OpManagerFactory.getInstance().logout));
     };
 
     WirecloudHeader.prototype._clearOldBreadcrum = function _clearOldBreadcrum() {
@@ -125,7 +143,7 @@
 
         this._clearOldBreadcrum();
 
-        if ('getBreadcrum' in newView) {
+        if (newView != null && 'getBreadcrum' in newView) {
             breadcrum = newView.getBreadcrum();
         } else {
             return;
@@ -139,7 +157,7 @@
         breadcrum_part.textContent = breadcrum_entry.label;
         breadcrum_part.className = breadcrum_levels[0];
         if ('class' in breadcrum_entry) {
-            breadcrum_part.addClassName(breadcrum_entry['class']);
+            breadcrum_part.classList.add(breadcrum_entry['class']);
         }
         this.breadcrum.appendChild(breadcrum_part);
 
@@ -153,10 +171,10 @@
             breadcrum_part.textContent = breadcrum_entry.label;
             breadcrum_part.className = breadcrum_levels[i];
             if ('class' in breadcrum_entry) {
-                breadcrum_part.addClassName(breadcrum_entry['class']);
+                breadcrum_part.classList.add(breadcrum_entry['class']);
             }
 
-            if ('menu' in breadcrum_entry) {
+            if (breadcrum_entry.menu != null) {
                 button = new StyledElements.PopupButton({
                     'plain': true,
                     'class': 'icon-menu',
@@ -173,20 +191,18 @@
         var menuitems, triangle, startx;
 
         if (this.currentMenu !== null) {
-            this.currentMenu.html_element.removeClassName('selected');
+            this.currentMenu.html_element.classList.remove('selected');
             this.submenu.className = 'submenu';
         }
 
         this.currentView = newView;
         this.currentMenu = this.menues[newView.view_name];
-        this.currentMenu.html_element.addClassName('selected');
+        this.currentMenu.html_element.classList.add('selected');
 
         this.refresh();
     };
 
     WirecloudHeader.prototype._notifyWorkspaceLoaded = function _notifyWorkspaceLoaded(workspace) {
-        this._paintBreadcrum(LayoutManagerFactory.getInstance().viewsByName['workspace']);
-
         workspace.wiring.addEventListener('load', function () {
             this.menues.wiring.html_element.classList.remove('error');
         }.bind(this));
