@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.unittest import TestCase
@@ -37,13 +36,13 @@ class WirecloudTestPlugin1(WirecloudPlugin):
     }
 
     def get_scripts(self, view):
-        if view == 'index':
+        if view == 'classic':
             return ('a.js', 'b.js')
         else:
             return ('a.js',)
 
-    def get_widget_api_extensions(self, view):
-        if view == 'index':
+    def get_widget_api_extensions(self, view, features):
+        if view == 'classic':
             return ('d.js',)
         else:
             return ()
@@ -71,11 +70,10 @@ class WirecloudPluginTestCase(TestCase):
         cls.OLD_WIRECLOUD_PLUGINS = getattr(settings, 'WIRECLOUD_PLUGINS', None)
         super(WirecloudPluginTestCase, cls).setUpClass()
 
-    @classmethod
-    def tearDown(cls):
-        settings.WIRECLOUD_PLUGINS = cls.OLD_WIRECLOUD_PLUGINS
+    def tearDown(self):
+        settings.WIRECLOUD_PLUGINS = self.OLD_WIRECLOUD_PLUGINS
         clear_cache()
-        super(WirecloudPluginTestCase, cls).tearDownClass()
+        super(WirecloudPluginTestCase, self).tearDown()
 
     def test_basic_conf(self):
 
@@ -84,10 +82,10 @@ class WirecloudPluginTestCase(TestCase):
 
         core_plugins = len(get_plugins())
         core_features = len(get_active_features())
-        core_index_javascripts = len(get_extra_javascripts('index'))
-        core_iphone_javascripts = len(get_extra_javascripts('iphone'))
-        core_index_extensions = len(get_widget_api_extensions('index'))
-        core_iphone_extensions = len(get_widget_api_extensions('iphone'))
+        core_classic_javascripts = len(get_extra_javascripts('classic'))
+        core_smartphone_javascripts = len(get_extra_javascripts('smartphone'))
+        core_classic_extensions = len(get_widget_api_extensions('classic', {}))
+        core_smartphone_extensions = len(get_widget_api_extensions('smartphone', {}))
 
         settings.WIRECLOUD_PLUGINS = (
             'wirecloud.platform.tests.plugins.WirecloudTestPlugin1',
@@ -97,10 +95,10 @@ class WirecloudPluginTestCase(TestCase):
 
         self.assertEqual(len(get_plugins()), core_plugins + 2)
         self.assertEqual(len(get_active_features()), core_features + 2)
-        self.assertEqual(len(get_extra_javascripts('index')), core_index_javascripts + 2)
-        self.assertEqual(len(get_extra_javascripts('iphone')), core_iphone_javascripts + 1)
-        self.assertEqual(len(get_widget_api_extensions('index')), core_index_extensions + 1)
-        self.assertEqual(len(get_widget_api_extensions('iphone')), core_iphone_extensions + 0)
+        self.assertEqual(len(get_extra_javascripts('classic')), core_classic_javascripts + 2)
+        self.assertEqual(len(get_extra_javascripts('smartphone')), core_smartphone_javascripts + 1)
+        self.assertEqual(len(get_widget_api_extensions('classic', {})), core_classic_extensions + 1)
+        self.assertEqual(len(get_widget_api_extensions('smartphone', {})), core_smartphone_extensions + 0)
 
     def test_several_plugins_with_the_same_feature(self):
         settings.WIRECLOUD_PLUGINS = (
