@@ -62,13 +62,13 @@ urlpatterns = patterns('wirecloud.platform.views',
     # Widgets
     url(r'^api/resources/?$',
         localcatalogue_views.ResourceCollection(permitted_methods=('GET', 'POST',)),
-        name='wirecloud_showcase.resource_collection'),
+        name='wirecloud.resource_collection'),
     url(r'^api/resource/(?P<vendor>[^/]+)/(?P<name>[^/]+)/(?P<version>[^/]+)/?$',
         localcatalogue_views.ResourceEntry(permitted_methods=('DELETE', 'GET')),
-        name='wirecloud_showcase.resource_entry'),
+        name='wirecloud.resource_entry'),
     url(r'^api/resource/(?P<vendor>[^/]+)/(?P<name>[^/]+)/(?P<version>[^/]+)/description/?$',
         localcatalogue_views.ResourceDescriptionEntry(permitted_methods=('GET',)),
-        name='wirecloud_showcase.resource_description_entry'),
+        name='wirecloud.resource_description_entry'),
     url(r'^api/widget/(?P<vendor>[^/]+)/(?P<name>[^/]+)/(?P<version>[^/]+)/xhtml/?$',
         widget_views.WidgetCodeEntry(permitted_methods=('GET',)),
         name='wirecloud.widget_code_entry'),
