@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -44,33 +44,30 @@ def get_workspace_description(workspace):
 def process_iwidget(workspace, iwidget, wiring, parametrization, readOnlyWidgets):
 
     widget = iwidget.widget
+    widget_description = widget.resource.get_template().get_resource_info()
     iwidget_id = str(iwidget.id)
     iwidget_params = {}
     if iwidget_id in parametrization:
         iwidget_params = parametrization[iwidget_id]
 
     # input and output endpoints
-    outputs = widget.get_related_events()
-
-    for output_endpoint in outputs:
+    for output_endpoint in widget_description['wiring']['outputs']:
         wiring['outputs'].append({
-            'name': output_endpoint.name,
-            'type': output_endpoint.type,
-            'label': output_endpoint.label,
-            'description': output_endpoint.description,
-            'friendcode': output_endpoint.friend_code,
+            'name': output_endpoint['name'],
+            'type': output_endpoint['type'],
+            'label': output_endpoint['label'],
+            'description': output_endpoint['description'],
+            'friendcode': output_endpoint['friendcode'],
         })
 
-    inputs = widget.get_related_slots()
-
-    for input_endpoint in inputs:
+    for input_endpoint in widget_description['wiring']['inputs']:
         wiring['inputs'].append({
-            'name': input_endpoint.name,
-            'type': input_endpoint.type,
-            'label': input_endpoint.label,
-            'description': input_endpoint.description,
-            'friendcode': input_endpoint.friend_code,
-            'actionlabel': input_endpoint.action_label,
+            'name': input_endpoint['name'],
+            'type': input_endpoint['type'],
+            'label': input_endpoint['label'],
+            'description': input_endpoint['description'],
+            'friendcode': input_endpoint['friendcode'],
+            'actionlabel': input_endpoint['actionlabel'],
         })
 
     # preferences
@@ -88,6 +85,9 @@ def process_iwidget(workspace, iwidget, wiring, parametrization, readOnlyWidgets
         else:
             value = get_variable_value_from_varname(workspace.creator, iwidget, pref.name)
 
+        if pref.type == 'B':
+            value = str(value).lower()
+
         preferences[pref.name] = {
             'readonly': status != 'normal',
             'hidden': status == 'hidden',
@@ -139,6 +139,7 @@ def process_iwidget(workspace, iwidget, wiring, parametrization, readOnlyWidgets
 
 def build_json_template_from_workspace(options, workspace, user):
     options['type'] = 'mashup'
+    options['params'] = []
     options['translations'] = {}
     options['translation_index_usage'] = {}
 
@@ -148,8 +149,8 @@ def build_json_template_from_workspace(options, workspace, user):
     else:
         options['description'] = description + '\n' + get_workspace_description(workspace)
 
-    if options.get('author', '').strip() == '':
-        options['author'] = unicode(user)
+    if options.get('authors', '').strip() == '':
+        options['authors'] = unicode(user)
 
     options['requirements'] = []
 
@@ -157,6 +158,10 @@ def build_json_template_from_workspace(options, workspace, user):
     parametrization = options.get('parametrization')
     if not parametrization:
         parametrization = {}
+    if 'iwidgets' not in parametrization:
+        parametrization['iwidgets'] = {}
+    if 'ioperators' not in parametrization:
+        parametrization['ioperators'] = {}
 
     # Workspace preferences
     options['preferences'] = {}
@@ -178,7 +183,7 @@ def build_json_template_from_workspace(options, workspace, user):
 
         resources = []
         for iwidget in tab.iwidget_set.select_related('widget__resource', 'position').all():
-            resources.append(process_iwidget(workspace, iwidget, options['wiring'], parametrization, readOnlyWidgets))
+            resources.append(process_iwidget(workspace, iwidget, options['wiring'], parametrization['iwidgets'], readOnlyWidgets))
 
         options['tabs'].append({
             'name': tab.name,
@@ -206,7 +211,7 @@ def build_json_template_from_workspace(options, workspace, user):
         vendor, name, version = operator['name'].split('/')
         resource = CatalogueResource.objects.get(vendor=vendor, short_name=name, version=version)
         operator_info = json.loads(resource.json_description)
-        operator_params = {}  # TODO for now, operator preferences cannot be parameterized
+        operator_params = parametrization['ioperators'].get(id_, {})
         for pref_index, preference in enumerate(operator_info['preferences']):
 
             status = 'normal'
@@ -218,9 +223,9 @@ def build_json_template_from_workspace(options, workspace, user):
                 value = ioperator_param_desc['value']
                 status = ioperator_param_desc['status']
             elif preference['name'] in operator['preferences']:
-                value = operator['preferences'][preference['name']]
+                value = operator['preferences'][preference['name']]['value']
             else:
-                value = preference['default_value']
+                value = preference['default']
 
             operator_data['preferences'][preference['name']] = {
                 'readonly': status != 'normal',
@@ -240,8 +245,10 @@ def build_json_template_from_workspace(options, workspace, user):
 
     options['wiring']['views'] = wiring_status.get('views', ())
 
+    return options
 
-def build_template_from_workspace(options, workspace, user):
+
+def build_xml_template_from_workspace(options, workspace, user):
 
     build_json_template_from_workspace(options, workspace, user)
 
