@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2011-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -28,13 +28,12 @@ from wirecloud.platform.context.utils import get_context_values
 from wirecloud.platform.get_data import TemplateValueProcessor
 from wirecloud.platform.widget.utils import get_or_add_widget_from_catalogue
 from wirecloud.platform.iwidget.utils import SaveIWidget
-from wirecloud.platform.localcatalogue.utils import get_or_add_resource_from_available_marketplaces
 from wirecloud.platform.preferences.views import update_tab_preferences, update_workspace_preferences
 from wirecloud.platform.models import Workspace, UserWorkspace
 from wirecloud.platform.workspace.utils import createTab
 
 
-def buildWorkspaceFromTemplate(template, user, allow_renaming=False):
+def buildWorkspaceFromTemplate(template, user, allow_renaming=False, new_name=None):
 
     if not isinstance(template, TemplateParser):
         template = TemplateParser(template)
@@ -42,7 +41,10 @@ def buildWorkspaceFromTemplate(template, user, allow_renaming=False):
     if template.get_resource_type() != 'mashup':
         raise Exception()
 
-    name = template.get_resource_name()
+    if new_name is not None:
+        name = new_name
+    else:
+        name = template.get_resource_name()
 
     # Workspace creation
     workspace = Workspace(name=name, creator=user)
@@ -59,6 +61,7 @@ def buildWorkspaceFromTemplate(template, user, allow_renaming=False):
 
     return (workspace, user_workspace)
 
+
 class MissingDependencies(Exception):
 
     def __init__(self, missing_dependencies):
@@ -67,12 +70,13 @@ class MissingDependencies(Exception):
     def __unicode__(self):
         return _('Missing dependencies')
 
+
 def check_mashup_dependencies(template, user):
 
     if not isinstance(template, TemplateParser):
         template = TemplateParser(template)
 
-    missing_dependencies = []
+    missing_dependencies = set()
     workspace_info = template.get_resource_info()
 
     for tab_entry in workspace_info['tabs']:
@@ -82,7 +86,7 @@ def check_mashup_dependencies(template, user):
                 if not catalogue_resource.is_available_for(user):
                     raise CatalogueResource.DoesNotExist
             except CatalogueResource.DoesNotExist:
-                missing_dependencies.append('/'.join((resource.get('vendor'), resource.get('name'), resource.get('version'))))
+                missing_dependencies.add('/'.join((resource.get('vendor'), resource.get('name'), resource.get('version'))))
 
     for id_, op in workspace_info['wiring']['operators'].iteritems():
         (vendor, name, version) = op['name'].split('/')
@@ -91,10 +95,11 @@ def check_mashup_dependencies(template, user):
             if not resource.is_available_for(user):
                 raise CatalogueResource.DoesNotExist
         except CatalogueResource.DoesNotExist:
-            missing_dependencies.append('/'.join((vendor, name, version)))
+            missing_dependencies.add('/'.join((vendor, name, version)))
 
     if len(missing_dependencies) > 0:
-        raise MissingDependencies(missing_dependencies)
+        raise MissingDependencies(list(missing_dependencies))
+
 
 def fillWorkspaceUsingTemplate(workspace, template):
 
@@ -106,8 +111,7 @@ def fillWorkspaceUsingTemplate(workspace, template):
 
     user = workspace.creator
 
-    user_workspace = UserWorkspace.objects.get(user=workspace.creator, workspace=workspace)
-    context_values = get_context_values(user_workspace)
+    context_values = get_context_values(workspace, workspace.creator)
     processor = TemplateValueProcessor({'user': user, 'context': context_values})
 
     workspace_info = template.get_resource_info()
@@ -126,10 +130,10 @@ def fillWorkspaceUsingTemplate(workspace, template):
     new_forced_values = {
         'extra_prefs': {},
         'iwidget': {},
+        'ioperator': {},
     }
-    for param_name in workspace_info['params']:
-        param = workspace_info['params'][param_name]
-        new_forced_values['extra_prefs'][param_name] = {
+    for param in workspace_info['params']:
+        new_forced_values['extra_prefs'][param['name']] = {
             'inheritable': False,
             'label': param.get('label'),
             'type': param.get('type'),
@@ -191,27 +195,12 @@ def fillWorkspaceUsingTemplate(workspace, template):
                 iwidget.readOnly = True
                 iwidget.save()
 
-            new_forced_values['iwidget'][str(iwidget.id)] = iwidget_forced_values
+            if len(iwidget_forced_values) > 0:
+                new_forced_values['iwidget'][str(iwidget.id)] = iwidget_forced_values
+
             iwidget_id_mapping[resource.get('id')] = iwidget
 
-    if workspace.forcedValues is not None and workspace.forcedValues != '':
-        forced_values = json.loads(workspace.forcedValues)
-    else:
-        forced_values = {
-            'extra_prefs': {},
-            'iwidget': {},
-        }
-
-    forced_values['extra_prefs'].update(new_forced_values['extra_prefs'])
-    forced_values['iwidget'].update(new_forced_values['iwidget'])
-    workspace.forcedValues = json.dumps(forced_values, ensure_ascii=False)
-
     # wiring
-    wiring_status = {
-        'operators': {},
-        'connections': [],
-    }
-
     if workspace.wiringStatus != '':
         workspace_wiring_status = json.loads(workspace.wiringStatus)
     else:
@@ -225,43 +214,49 @@ def fillWorkspaceUsingTemplate(workspace, template):
         workspace_wiring_status['views'] = []
 
     max_id = 0
-    operators = {}
+    ioperator_id_mapping = {}
 
     for id_ in workspace_wiring_status['operators'].keys():
         if int(id_) > max_id:
             max_id = int(id_)
 
-    # Change string ids by integer ids and install unavailable operators
-    for id_, op in workspace_info['wiring']['operators'].iteritems():
+    wiring_status = {
+        'operators': workspace_wiring_status['operators'],
+        'connections': workspace_wiring_status['connections'],
+    }
+
+    # Process operators info
+    for operator_id, operator in workspace_info['wiring']['operators'].iteritems():
         max_id += 1
-        #mapping between string ids and integer id
-        operators[id_] = max_id
-        wiring_status['operators'][max_id] = {
-            'id': max_id,
-            'name': op['name']
+        new_id = unicode(max_id)
+        ioperator_id_mapping[operator_id] = new_id
+        wiring_status['operators'][new_id] = {
+            'id': new_id,
+            'name': operator['name'],
+            'preferences': operator['preferences'],
         }
-        op_id_args = op['name'].split('/')
-        op_id_args.append(user)
-        get_or_add_resource_from_available_marketplaces(*op_id_args)
 
-    wiring_status['operators'].update(workspace_wiring_status['operators'])
+        ioperator_forced_values = {}
+        for pref_id, pref in operator['preferences'].iteritems():
+            if pref.get('readonly', False):
+                ioperator_forced_values[pref_id] = {'value': pref.get('value'), 'hidden': pref.get('hidden', False)}
 
-    if workspace_wiring_status['connections']:
-        wiring_status['connections'] = workspace_wiring_status['connections']
+        if len(ioperator_forced_values) > 0:
+            new_forced_values['ioperator'][new_id] = ioperator_forced_values
 
     for connection in workspace_info['wiring']['connections']:
-        source_id = connection['source']['id']
-        target_id = connection['target']['id']
+        source_id = str(connection['source']['id'])
+        target_id = str(connection['target']['id'])
 
         if connection['source']['type'] == 'iwidget':
             source_id = iwidget_id_mapping[source_id].id
         elif connection['source']['type'] == 'ioperator':
-            source_id = operators[source_id]
+            source_id = ioperator_id_mapping[source_id]
 
         if connection['target']['type'] == 'iwidget':
             target_id = iwidget_id_mapping[target_id].id
         elif connection['target']['type'] == 'ioperator':
-            target_id = operators[target_id]
+            target_id = ioperator_id_mapping[target_id]
 
         wiring_status['connections'].append({
             'readOnly': connection['readonly'],
@@ -287,7 +282,7 @@ def fillWorkspaceUsingTemplate(workspace, template):
 
             operators_views = {}
             for key, operator in wiring_view['operators'].iteritems():
-                operators_views[operators[key]] = operator
+                operators_views[ioperator_id_mapping[key]] = operator
 
             wiring_status['views'].append({
                 'iwidgets': iwidgets_views,
@@ -299,4 +294,25 @@ def fillWorkspaceUsingTemplate(workspace, template):
 
     workspace.wiringStatus = json.dumps(wiring_status)
 
+    # Forced values
+    if workspace.forcedValues is not None and workspace.forcedValues != '':
+        forced_values = json.loads(workspace.forcedValues)
+    else:
+        forced_values = {
+            'extra_prefs': {},
+            'iwidget': {},
+            'ioperator': {},
+        }
+
+    if 'ioperator' not in forced_values:
+        forced_values['ioperator'] = {}
+
+    if 'iwidget' not in forced_values:
+        forced_values['iwidget'] = {}
+
+    forced_values['extra_prefs'].update(new_forced_values['extra_prefs'])
+    forced_values['iwidget'].update(new_forced_values['iwidget'])
+    forced_values['ioperator'].update(new_forced_values['ioperator'])
+    workspace.forcedValues = json.dumps(forced_values, ensure_ascii=False)
+
     workspace.save()
