@@ -31,7 +31,6 @@ try:
 except: # Django 1.4
     from django.http import HttpResponse as StreamingHttpResponse
 from django.utils.encoding import iri_to_uri
-from django.utils.http import urlquote
 from django.utils.translation import ugettext as _
 
 from wirecloud.commons.utils.http import build_error_response, get_current_domain
@@ -150,7 +149,7 @@ class Proxy():
             return HttpResponse(status=502)
 
         # Build a Django response
-        response = StreamingHttpResponse(res.raw)
+        response = StreamingHttpResponse(res.raw.stream(4096, decode_content=False))
 
         # Set status code to the response
         response.status_code = res.status_code
